<?php
/*
Plugin Name: Simple Image Link
Plugin URI: http://blog-well.com/downloads/wordpress-image-link-plugin/
Description: A simple way to add an image with a link to your sidebar
Author: BlogWell
Version: 1.2
Author URI: http://blog-well.com/
*/

/*
Copyright (C) 2008 blog-well.com (mad AT blog-well DOT com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Kudos to the WordPress guys who added the "Pattern for multi-widget" in their code - this could not have been created without this template

define('SIMPLEIMAGELINK_VERSION', 1);	// Version number of the properties saved - used to set meaningful defaults when new properties added.

if (!function_exists(widget_simpleimagelink_header))
{
	function widget_simpleimagelink_header($args)
	{	
		$blogroot = get_bloginfo('siteurl');
		$simpleimagelinkhead = "\n\t<!-- ImageLink widget -->\n\t<link rel='stylesheet' href='".$blogroot."/wp-content/plugins/".basename(dirname(__FILE__))."/simple-image-link.css' type='text/css' media='screen' />\n";
		print($simpleimagelinkhead);
	}
}

// Displays widget on blag
// $widget_args: number
//    number: which of the several widgets of this type do we mean
function widget_simpleimagelink( $args, $widget_args = 1 ) 
{
	extract( $args, EXTR_SKIP );
	if ( is_numeric($widget_args) )
		$widget_args = array( 'number' => $widget_args );
	$widget_args = wp_parse_args( $widget_args, array( 'number' => -1 ) );
	extract( $widget_args, EXTR_SKIP );

	// Data should be stored as array:  array( number => data for that instance of the widget, ... )
	$options = get_option('widget_simpleimagelink');
	if ( !isset($options[$number]) )
		return;

	$version = $options[$number]['version'];
	$title = apply_filters('widget_title', $options[$number]['title']);
	$showTitle = apply_filters('widget_title', $options[$number]['showTitle']);
	$alt = $options[$number]['alt'];
	$showPopup = $options[$number]['showPopup'];
	$img = $options[$number]['img'];
	$imgWidth = $options[$number]['imgWidth'];
	$imgHeight = $options[$number]['imgHeight'];
	$url = $options[$number]['url'];
	$urlTarget = $options[$number]['urlTarget'];
	$noFollow = $options[$number]['noFollow'];
	$paddingTop = $options[$number]['paddingTop'];
	$paddingBottom = $options[$number]['paddingBottom'];
	$alignment = $options[$number]['alignment'];
	$text = $options[$number]['text'];
	$break = $options[$number]['break'];

	if (empty($alignment)) $alignment = "center";

	if (empty($version) || ($version < SIMPLEIMAGELINK_VERSION))
	{
		// Logic here to define meaningful defaults to properties added in updates
	}
	
	$aAttribs = "";
	$imgStyle = "";
	$divStyle = "";
	$imgAttribs = "";
	$divAttribs = "";

	if (!empty($imgWidth))      { $imgStyle .= " width:" . $imgWidth . ";"; }
	if (!empty($imgHeight))     { $imgStyle .= " height:" . $imgHeight . ";"; }
	if (!empty($paddingTop))    { $divStyle .= " padding-top:" . $paddingTop . ";"; }
	if (!empty($paddingBottom)) { $divStyle .= " padding-bottom:" . $paddingBottom . ";"; }

	if (!empty($imgStyle))      { $imgAttribs .= " style='" . $imgStyle . "'"; }
	if (!empty($divStyle))      { $divAttribs .= " style='" . $divStyle . "'"; }
	
	if (!empty($urlTarget))     { $aAttribs .= " target='" . $urlTarget . "'"; }
	if ($noFollow == 1)         { $aAttribs .= " rel='nofollow'"; }
	
	if (!empty($alt))
	  $imgAttribs .= " alt='" . $alt . "'";
	if ($showPopup == 1)
	  $aAttribs .= " title='" . $alt . "'";

	echo $before_widget;
	echo "<div class='widget_simpleimagelink_container' " . $divAttribs .">";
	
	// Highlight the fact that the image is not defined by enclosing the title within those << & >> characters.
	if (empty($img))
		$title = '&laquo;' . $title . '&raquo;';
	
	if (!empty($title))
	{
	  // If we are  not to show the title, then enclose it within a div which will stop it from being displayed
		if ($showTitle != 1) { echo "<div class='widget_simpleimagelink_hidetitle'>"; }
		echo $before_title . $title . $after_title;
		if ($showTitle != 1) { echo "</div>"; }
	}

	if (!empty($img))
	{
		echo "<div class='widget_simpleimagelink' style='text-align:" . $alignment . "'>";
		if (!empty($url)) echo "<a href='" . $url . "' " . $aAttribs . ">";
		echo "<img src='" . $img ."' " . $imgAttribs . " />";
		if (!empty($text))
		{
			echo $break ? "<br />" : "&nbsp;";
			echo $text;
		}
		if (!empty($url)) echo "</a>";
		echo "</div>";
	}
	
	echo "</div>";
	echo $after_widget;
}

function widget_simpleimagelink_fixupUnits($value, $allowEM = false)
{
	if (!empty($value))
	{
		if (preg_match('|^[0-9]+$|', $value))
			$value .= 'px';
		else if ($allowEM && preg_match('|^[0-9]+(\.[0-9]+){0,1}$|', $value))
			$value .= 'em';
	}
	return $value;
}

function widget_simpleimagelink_control( $widget_args = 1 ) 
{
	global $wp_registered_widgets;
	static $updated = false; // Whether or not we have already updated the data after a POST submit

	if ( is_numeric($widget_args) )
		$widget_args = array( 'number' => $widget_args );
	$widget_args = wp_parse_args( $widget_args, array( 'number' => -1 ) );
	extract( $widget_args, EXTR_SKIP );

	// Data should be stored as array:  array( number => data for that instance of the widget, ... )
	$options = get_option('widget_simpleimagelink');
	if ( !is_array($options) )
		$options = array();

	// We need to update the data
	if ( !$updated && !empty($_POST['sidebar']) ) 
	{
		// Tells us what sidebar to put the data in
		$sidebar = (string) $_POST['sidebar'];

		$sidebars_widgets = wp_get_sidebars_widgets();
		if ( isset($sidebars_widgets[$sidebar]) )
			$this_sidebar =& $sidebars_widgets[$sidebar];
		else
			$this_sidebar = array();

		foreach ( $this_sidebar as $_widget_id ) 
		{
			// Remove all widgets of this type from the sidebar.  We'll add the new data in a second.  This makes sure we don't get any duplicate data
			// since widget ids aren't necessarily persistent across multiple updates
			if ( 'widget_simpleimagelink' == $wp_registered_widgets[$_widget_id]['callback'] && isset($wp_registered_widgets[$_widget_id]['params'][0]['number']) ) 
			{
				$widget_number = $wp_registered_widgets[$_widget_id]['params'][0]['number'];
				if ( !in_array( "simpleimagelink-$widget_number", $_POST['widget-id'] ) ) // the widget has been removed. "simpleimagelink-$widget_number" is "{id_base}-{widget_number}
					unset($options[$widget_number]);
			}
		}

		foreach ( (array) $_POST['widget-simpleimagelink'] as $widget_number => $widget_instance ) 
		{
			// compile data from $widget_instance
			if ( !isset($widget_instance['title']) && isset($options[$widget_number]) ) // user clicked cancel
				continue;
				
			$version = trim(wp_specialchars( $widget_instance['version'] ));
			$title = trim(wp_specialchars( $widget_instance['title'] ));
			$showTitle = trim(wp_specialchars( $widget_instance['showTitle'] ));
			$alt = trim(wp_specialchars( $widget_instance['alt'] ));
			$showPopup = trim(wp_specialchars( $widget_instance['showPopup'] ));
			$img = trim(wp_specialchars( $widget_instance['img'] ));
			$imgWidth = widget_simpleimagelink_fixupUnits(trim(wp_specialchars( $widget_instance['imgWidth'] )));
			$imgHeight = widget_simpleimagelink_fixupUnits(trim(wp_specialchars( $widget_instance['imgHeight'] )));
			$url = trim(wp_specialchars( $widget_instance['url'] ));
			$urlTarget = trim(wp_specialchars( $widget_instance['urlTarget'] ));
			$noFollow = trim(wp_specialchars( $widget_instance['noFollow'] ));
			$paddingTop = widget_simpleimagelink_fixupUnits(trim(wp_specialchars( $widget_instance['paddingTop'] )), true);
			$paddingBottom = widget_simpleimagelink_fixupUnits(trim(wp_specialchars( $widget_instance['paddingBottom'] )), true);
			$alignment = trim(wp_specialchars( $widget_instance['alignment'] ));
			$text = trim(wp_specialchars( $widget_instance['text'] ));
			$break = trim(wp_specialchars( $widget_instance['break'] ));
			
			if (empty($version) || ($version < SIMPLEIMAGELINK_VERSION))
			{
				// Logic here to define meaningful defaults to properties added in updates
			}

			$options[$widget_number] = array( 'version' => SIMPLEIMAGELINK_VERSION,
			                                  'title' => $title, 
			                                  'showTitle' => $showTitle, 
			                                  'alt' => $alt, 
																				'showPopup' => $showPopup,
																				'img' => $img, 
																				'imgWidth' => $imgWidth, 
																				'imgHeight' => $imgHeight, 
																				'url' => $url,
																				'urlTarget' => $urlTarget,
																				'noFollow' => $noFollow,
																				'paddingTop' => $paddingTop,
																				'paddingBottom' => $paddingBottom,
																				'alignment' => $alignment,
																				'text' => $text,
																				'break' => $break);
		}

		update_option('widget_simpleimagelink', $options);

		$updated = true; // So that we don't go through this more than once
	}

	// Here we echo out the form
	if ( -1 == $number )
	{
	  $version = SIMPLEIMAGELINK_VERSION;
		$title = '';
		$showTitle = 0;
		$alt = '';
		$showPopup = 1;
		$img = '';
		$imgWidth = '';
		$imgHeight = '';
		$url = '';
		$urlTarget = '';
		$noFollow = 1;
		$paddingTop = '';
		$paddingBottom = '';
		$alignment = 'center';
		$text = '';
		$break = 0;
		$number = '%i%';
	}
	else
	{
		$version = attribute_escape($options[$number]['version']);
		$title = attribute_escape($options[$number]['title']);
		$showTitle = attribute_escape($options[$number]['showTitle']);
		$alt = attribute_escape($options[$number]['alt']);
		$showPopup = attribute_escape($options[$number]['showPopup']);
		$img = attribute_escape($options[$number]['img']);
		$imgWidth = attribute_escape($options[$number]['imgWidth']);
		$imgHeight = attribute_escape($options[$number]['imgHeight']);
		$url = attribute_escape($options[$number]['url']);
		$urlTarget = attribute_escape($options[$number]['urlTarget']);
		$noFollow = attribute_escape($options[$number]['noFollow']);
		$paddingTop = attribute_escape($options[$number]['paddingTop']);
		$paddingBottom = attribute_escape($options[$number]['paddingBottom']);
		$alignment = attribute_escape($options[$number]['alignment']);
		$text = attribute_escape($options[$number]['text']);
		$break = attribute_escape($options[$number]['break']);
		if (empty($alignment)) $alignment = 'center';
	}
	
	if (empty($version) || ($version < SIMPLEIMAGELINK_VERSION))
	{
		// Logic here to define meaningful defaults to properties added in updates
	}
	
?>
	<p>
		<?php echo(__("Title (optional)")); ?>: <input class="widefat" id="widget-simpleimagelink-title-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][title]" type="text" value="<?php echo $title; ?>" />
	</p>
	<p>
		<label for="widget-simpleimagelink-showTitle-<?php echo $number; ?>"><input id="widget-simpleimagelink-showTitle-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][showTitle]" type="checkbox" value="1" <?php if ($showTitle == 1) { echo " checked='yes'"; } ?>/> <?php echo(__("Display title")); ?></label>
	</p>
	<p>
		<?php echo(__("Image location (required)")); ?>: <input class="widefat" id="widget-simpleimagelink-img-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][img]" type="text" value="<?php echo $img; ?>" />
	</p>
	<p>
		<?php echo(__("Image dimensions - e.g. 123px or 50% (optional)")); ?><br />
		<?php echo(__("Width")); ?>: <input class="narrowfat" id="widget-simpleimagelink-imgWidth-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][imgWidth]" type="text" value="<?php echo $imgWidth; ?>" />
		&nbsp;&nbsp;&nbsp;<?php echo(__("Height")); ?>: <input class="narrowfat" id="widget-simpleimagelink-imgHeight-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][imgHeight]" type="text" value="<?php echo $imgHeight; ?>" />
	</p>
	<p>
		<?php echo(__("Image alt text (optional)")); ?>: <input class="widefat" id="widget-simpleimagelink-alt-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][alt]" type="text" value="<?php echo $alt; ?>" />
	</p>
	<p>
		<?php echo(__("Text to display after image (optional)")); ?>: <input class="widefat" id="widget-simpleimagelink-text-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][text]" type="text" value="<?php echo $text; ?>" />
	</p>
	<p>
		<label for="widget-simpleimagelink-break-<?php echo $number; ?>"><input id="widget-simpleimagelink-break-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][break]" type="checkbox" value="1" <?php if ($break == 1) { echo " checked='yes'"; } ?>/> <?php echo(__("Break between image and text")); ?></label>
	</p>
	<p>
		<?php echo(__("Alignment")); ?>: <select class="widefat" id="widget-simpleimagelink-alignment-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][alignment]">
  		<option value="left" <?php if ($alignment == 'left') echo 'selected="selected"'; ?>><?php echo(__("Left")); ?></option>
  		<option value="center" <?php if ($alignment == 'center') echo 'selected="selected"'; ?>><?php echo(__("Center")); ?></option>
  		<option value="right" <?php if ($alignment == 'right') echo 'selected="selected"'; ?>><?php echo(__("Right")); ?></option>
		</select>
	</p>
	<p>
		<?php echo(__("Link location (optional)")); ?>: <input class="widefat" id="widget-simpleimagelink-url-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][url]" type="text" value="<?php echo $url; ?>" />
	</p>
	<p>
		<?php echo(__("Link target")); ?>: <select class="widefat" id="widget-simpleimagelink-urlTarget-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][urlTarget]">
  		<option value ="" <?php if ($urlTarget != '_blank') echo 'selected="selected"'; ?>><?php echo(__("Open link in the same window")); ?></option>
	  	<option value ="_blank" <?php if ($urlTarget == '_blank') echo 'selected="selected"'; ?>><?php echo(__("Open link in a new window")); ?></option>
		</select><br />
		<label for="widget-simpleimagelink-noFollow-<?php echo $number; ?>"><input id="widget-simpleimagelink-noFollow-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][noFollow]" type="checkbox" value="1" <?php if ($noFollow == 1) { echo " checked='yes'"; } ?>/> <?php echo(__("Use nofollow on link (recommended for advertisements)")); ?></label>
	</p>
	<p>
		<label for="widget-simpleimagelink-showPopup-<?php echo $number; ?>"><input id="widget-simpleimagelink-showPopup-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][showPopup]" type="checkbox" value="1" <?php if ($showPopup == 1) { echo " checked='yes'"; } ?>/> <?php echo(__("Display image alt text as link popup (i.e. anchor title)")); ?></label>
	</p>
	<p>
		<?php echo(__("Additional padding - e.g. 10px or 1.0em (optional)")); ?><br />
		<?php echo(__("Above")); ?>: <input class="narrowfat" id="widget-simpleimagelink-paddingTop-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][paddingTop]" type="text" value="<?php echo $paddingTop; ?>" />
		&nbsp;&nbsp;&nbsp;<?php echo(__("Below")); ?>: <input class="narrowfat" id="widget-simpleimagelink-paddingBottom-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][paddingBottom]" type="text" value="<?php echo $paddingBottom; ?>" />
		<input type="hidden" id="widget-simpleimagelink-submit-<?php echo $number; ?>" name="widget-simpleimagelink[<?php echo $number; ?>][submit]" value="1" />
	</p>
<?php
}

// Registers each instance of our widget on startup
function widget_simpleimagelink_init() 
{
	if ( !$options = get_option('widget_simpleimagelink') )
		$options = array();

	$widget_ops = array('classname' => 'widget_simpleimagelink', 'description' => __('Displays an image which has a link attached to it.'));
	$control_ops = array('width' => 400, 'height' => 350, 'id_base' => 'simpleimagelink');
	$name = __('Simple Image Link');

	$registered = false;
	foreach ( array_keys($options) as $o ) 
	{
		// Old widgets can have null values for some reason
		if ( !isset($options[$o]['title']) )
			continue;

		// $id should look like {$id_base}-{$o}
		$id = "simpleimagelink-$o"; // Never never never translate an id
		$registered = true;
		wp_register_sidebar_widget( $id, $name, 'widget_simpleimagelink', $widget_ops, array( 'number' => $o ) );
		wp_register_widget_control( $id, $name, 'widget_simpleimagelink_control', $control_ops, array( 'number' => $o ) );
	}

	// If there are none, we register the widget's existance with a generic template
	if ( !$registered ) 
	{
		wp_register_sidebar_widget( 'simpleimagelinkimagelink-1', $name, 'widget_simpleimagelink', $widget_ops, array( 'number' => -1 ) );
		wp_register_widget_control( 'simpleimagelinkimagelink-1', $name, 'widget_simpleimagelink_control', $control_ops, array( 'number' => -1 ) );
	}
}

add_action("wp_head", "widget_simpleimagelink_header");
add_action("admin_head", "widget_simpleimagelink_header");
add_action("plugins_loaded", "widget_simpleimagelink_init");

?>
